@@ -15,7 +15,7 @@ use Color::ANSI::Util qw(ansi16fg ansi16bg
 use Scalar::Util 'looks_like_number';
 use Text::ANSI::Util qw(ta_mbswidth_height ta_mbpad ta_add_color_resets);
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 my $ATTRS = [qw(
 
@@ -236,9 +236,11 @@ sub BUILD {
         } elsif ($self->{use_color}) {
             my $bg = $self->_detect_terminal->{default_bgcolor} // '';
             if ($self->{color_depth} >= 2**24) {
-                $ct = 'Default::default_gradation' . ($bg eq 'ffffff' ? '_whitebg' : '');
+                $ct = 'Default::default_gradation' .
+                    ($bg eq 'ffffff' ? '_whitebg' : '');
             } else {
-                $ct = 'Default::default_nogradation' . ($bg eq 'ffffff' ? '_whitebg' : '');;
+                $ct = 'Default::default_nogradation' .
+                    ($bg eq 'ffffff' ? '_whitebg' : '');;
             }
         } else {
             $ct = 'Default::no_color';
@@ -548,10 +550,18 @@ sub _detect_column_types {
             if ($col =~ /\?/) {
                 $type = 'bool';
                 last DETECT;
-            } elsif ($col =~ /date\b|\b[acmsu]?time\b/i) {
-                $type = 'date';
-                last DETECT;
             }
+
+            require Parse::VarName;
+            my @words = map {lc} @{ Parse::VarName::split_varname_words(
+                varname=>$col) };
+            for (qw/date time ctime mtime utime atime stime/) {
+                if ($_ ~~ @words) {
+                    $type = 'date';
+                    last DETECT;
+                }
+            }
+
             my $pass = 1;
             for my $j (0..@$rows) {
                 my $v = $rows->[$j][$i];
@@ -573,9 +583,10 @@ sub _detect_column_types {
             $res->{align}   = 'center';
             $res->{valign}  = 'center';
             $res->{fgcolor} = $ct->{colors}{bool_data};
-            $res->{formats} = [[bool => {style => $self->{use_utf8} ? "check_cross" : "Y_N"}]];
+            $res->{formats} = [[bool => {style => $self->{use_utf8} ?
+                                             "check_cross" : "Y_N"}]];
         } elsif ($type eq 'date') {
-            $res->{align}   = 'right';
+            $res->{align}   = 'middle';
             $res->{fgcolor} = $ct->{colors}{date_data};
             $res->{formats} = [['date' => {}]];
         } elsif ($type eq 'num') {
@@ -589,7 +600,8 @@ sub _detect_column_types {
         }
     }
 
-    $self->{_draw}{fcol_detect} = $fcol_detect;
+    #use Data::Dump; dd $fcol_detect;
+    $fcol_detect;
 }
 
 sub _read_style_envs {
@@ -605,9 +617,10 @@ sub _read_style_envs {
             my $s = $ss->{$col};
             for my $k (keys %$s) {
                 my $v = $s->{$k};
-            die "Unknown column style '$k' (for column $col) in ANSITABLE_COLUMN_STYLES environment, ".
-                "please use one of [".join(", ", @$COLUMN_STYLES)."]"
-                    unless $k ~~ $COLUMN_STYLES;
+            die "Unknown column style '$k' (for column $col) in ".
+                "ANSITABLE_COLUMN_STYLES environment, ".
+                    "please use one of [".join(", ", @$COLUMN_STYLES)."]"
+                        unless $k ~~ $COLUMN_STYLES;
                 $self->{_column_styles}[$ci]{$k} //= $v;
             }
         }
@@ -620,9 +633,10 @@ sub _read_style_envs {
             my $s = $ss->{$row};
             for my $k (keys %$s) {
                 my $v = $s->{$k};
-            die "Unknown row style '$k' (for row $row) in ANSITABLE_ROW_STYLES environment, ".
-                "please use one of [".join(", ", @$ROW_STYLES)."]"
-                    unless $k ~~ $ROW_STYLES;
+            die "Unknown row style '$k' (for row $row) in ".
+                "ANSITABLE_ROW_STYLES environment, ".
+                    "please use one of [".join(", ", @$ROW_STYLES)."]"
+                        unless $k ~~ $ROW_STYLES;
                 $self->{_row_styles}[$row]{$k} //= $v;
             }
         }
@@ -632,17 +646,19 @@ sub _read_style_envs {
         require JSON;
         my $ss = JSON::decode_json($ENV{ANSITABLE_CELL_STYLES});
         for my $cell (keys %$ss) {
-            die "Invalid cell specification in ANSITABLE_CELL_STYLES: $cell, please use 'row,col'"
-                unless $cell =~ /^(.+),(.+)$/;
+            die "Invalid cell specification in ANSITABLE_CELL_STYLES: ".
+                "$cell, please use 'row,col'"
+                    unless $cell =~ /^(.+),(.+)$/;
             my $row = $1;
             my $col = $2;
             my $ci = $self->_colnum($col);
             my $s = $ss->{$cell};
             for my $k (keys %$s) {
                 my $v = $s->{$k};
-            die "Unknown cell style '$k' (for row $row) in ANSITABLE_CELL_STYLES environment, ".
-                "please use one of [".join(", ", @$CELL_STYLES)."]"
-                    unless $k ~~ $CELL_STYLES;
+            die "Unknown cell style '$k' (for row $row) in ".
+                "ANSITABLE_CELL_STYLES environment, ".
+                    "please use one of [".join(", ", @$CELL_STYLES)."]"
+                        unless $k ~~ $CELL_STYLES;
                 $self->{_cell_styles}[$row][$ci]{$k} //= $v;
             }
         }
@@ -677,7 +693,8 @@ sub _prepare_draw {
     if (ref($cf) eq 'CODE') {
         $fcols = [grep {$cf->($_)} @$cols];
     } elsif (ref($cf) eq 'ARRAY') {
-        $fcols = $cf;
+        $fcols = [grep {defined} map {looks_like_number($_) ?
+                                          $cols->[$_] : $_} @$cf];
     } else {
         $fcols = $cols;
     }
@@ -705,7 +722,7 @@ sub _prepare_draw {
     my $frow_separators = [];
     my $frow_orig_indices = []; # needed when accessing original row data
     {
-        my $tpad = $self->{cell_tpad} // $self->{cell_vpad}; # tbl-lvl top padding
+        my $tpad = $self->{cell_tpad} // $self->{cell_vpad}; # tbl-lvl top pad
         my $bpad = $self->{cell_bpad} // $self->{cell_vpad}; # tbl-lvl botom pad
         my $i = -1;
         my $j = -1;
@@ -1126,7 +1143,8 @@ sub _get_data_cell_lines {
     my $ct   = $self->{color_theme};
     my $oy   = $self->{_draw}{frow_orig_indices}[$y];
     my $cell = $self->{_draw}{frows}[$y][$x];
-    my $args = {row_num=>$y, col_num=>$x, data=>$cell, orig_data=>$self->{rows}[$oy][$x]};
+    my $args = {row_num=>$y, col_num=>$x, data=>$cell,
+                orig_data=>$self->{rows}[$oy][$x]};
 
     my $tmp;
     my $fgcolor;
@@ -1341,7 +1359,7 @@ Text::ANSITable - Create a nice formatted table using extended ASCII and ANSI co
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -2255,10 +2273,10 @@ row span? column span?
 
 =head1 SEE ALSO
 
-For collections of border styles, search for <Text::ANSITable::BorderStyle::*>
+For collections of border styles, search for C<Text::ANSITable::BorderStyle::*>
 modules.
 
-For collections of color themes, search for <Text::ANSITable::ColorTheme::*>
+For collections of color themes, search for C<Text::ANSITable::ColorTheme::*>
 modules.
 
 Other table-formatting modules: L<Text::Table>, L<Text::SimpleTable>,
